#
# spec file for package wv2
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wv2
Version:        0.4.2
Release:        26.2
Summary:        Library for Importing Microsoft Word (tm) Documents
License:        LGPL-2.1-or-later
Group:          Productivity/Publishing/Word
URL:            https://sourceforge.net/projects/wvware
Source0:        https://sourceforge.net/projects/wvware/files/%{name}-%{version}.tar.bz2
Source1:        https://sourceforge.net/projects/wvware/files/%{name}-%{version}.tar.bz2.asc
Source2:        %{name}.keyring
Patch0:         glib_include.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libgsf-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The wv2 library is used to import Microsoft Word documents in koffice
for example.

%package -n libwv2-4
Summary:        Library for Importing Microsoft Word (tm) Documents
Group:          System/Libraries

%description -n libwv2-4
The wv2 library is used to import Microsoft Word documents in koffice
for example.

%package devel
Summary:        Library for Importing Microsoft Word(tm) Documents - development files
Group:          Development/Libraries/C and C++
Requires:       lib%{name}-4 = %{version}
Requires:       libgsf-devel
Requires:       libstdc++-devel

%description devel
The wv2 library is used to import Microsoft Word documents in koffice
for example.

%prep
%autosetup -p1

%build
export CXXFLAGS="%optflags -fvisibility-inlines-hidden"
# build fails with %%cmake macro
cmake \
	-DCMAKE_INSTALL_PREFIX=%{_prefix} \
	%if "%{_lib}" == "lib64"
	-DLIB_SUFFIX=64 \
	%endif

make VERBOSE=1 %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
  mkdir -p %{buildroot}%{_defaultdocdir}/wv2/
  cp -a doc AUTHORS README TODO COPYING.LIB \
        %{buildroot}%{_defaultdocdir}/wv2/
  rm -rf %{buildroot}%{_defaultdocdir}/wv2/doc/escher/CVS
  rm -rf %{buildroot}%{_defaultdocdir}/wv2/doc/CVS
  rm -rf %{buildroot}%{_defaultdocdir}/wv2/doc/.cvsignore

%post -n libwv2-4 -p /sbin/ldconfig

%postun -n libwv2-4 -p /sbin/ldconfig

%files -n libwv2-4
%defattr(-, root, root)
%dir %{_defaultdocdir}/wv2
%{_defaultdocdir}/wv2/AUTHORS
%{_defaultdocdir}/wv2/COPYING.LIB
/%{_libdir}/libwv2.so.*

%files devel
%defattr(-, root, root)
%dir %{_defaultdocdir}/wv2
%{_defaultdocdir}/wv2/doc
%{_defaultdocdir}/wv2/README
%{_defaultdocdir}/wv2/TODO
%{_bindir}/wv2-config
%{_includedir}/wv2
%{_libdir}/libwv2.so
%{_libdir}/wvWare

%changelog
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Thu Jul  7 2022 Marcus Meissner <meissner@suse.com>
- switch to https urls
* Thu Mar  5 2015 jengelh@inai.de
- Remove spurious bzip2 requirement from devel subpackage.
- %%doc is implicit for files in defaultdocdir anyway.
* Wed Mar  4 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- User url for source
- Add gpg signature
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sun Jan 22 2012 crrodriguez@opensuse.org
- Build with -fvisibility-inlines-hidden, saves around 2k
  entries in the exported symbol table
* Mon Jan  9 2012 sweet_f_a@gmx.de
- add glib_include.patch to fix
  "Only <glib.h> can be included directly."
* Tue Nov 29 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
- Pick appropriate package egroups
* Tue Nov 29 2011 ro@suse.de
- use _lib macro to properly determine lib suffix
* Thu Feb 25 2010 dimstar@opensuse.org
- Update to 0.4.2:
  + Basic support for images
  + Basic support for tables
  + Changed build system to cmake
- Drop patches wv2-gcc43.patch and wv2-diff.patch
- BuildRequire cmake
- Rename the library package according SLPP to libwv2-4
* Sat Jan 17 2009 crrodriguez@suse.de
- remove "la" files
* Sat Jun 28 2008 meissner@suse.de
- disabled static altogether
* Tue Oct 23 2007 meissner@suse.de
- fixed gcc 4.3 build
* Sun Oct 29 2006 meissner@suse.de
- use RPM_OPT_FLAGS, and stack protector.
* Wed Jun 28 2006 dmueller@suse.de
- update to 0.2.3
  * incorporate integer overflow check
  * fix small tab expand issue
* Wed Jun 28 2006 ltinkl@suse.cz
- fix #183984 - VUL-0: wv2 missing bounds check
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Sep 26 2005 mls@suse.de
- make devel package require base package
* Mon Jul 25 2005 mmj@suse.de
- fix build
- fix dependency chain
* Mon May 10 2004 adrian@suse.de
- update to version 0.2.2
* Thu Feb 26 2004 hmacht@suse.de
- building as nonroot-user
* Sat Jan 31 2004 adrian@suse.de
- wv2-devel requires now libgsf-devel
* Thu Nov  6 2003 adrian@suse.de
- update to version 0.2.1
* Tue Sep  2 2003 adrian@suse.de
- update to version 0.1.9
  * Word8 support fixes
  * --disable-debug switch to stop debug output
* Fri Aug  8 2003 adrian@suse.de
- update to version 0.1.8
* Fri Aug  1 2003 adrian@suse.de
- update to version 0.1.7
* Tue Jul 29 2003 adrian@suse.de
- fix build on lib64
* Mon Jul 28 2003 adrian@suse.de
- fix build
- add %%run_ldconfig
* Tue Jul 15 2003 adrian@suse.de
- update to version 0.1
* Sun May 18 2003 adrian@suse.de
- remove also .cvsignore
* Fri May 16 2003 adrian@suse.de
- fix build (remove CVS dirs)
* Mon Apr 14 2003 adrian@suse.de
- fix build for lib64
* Tue Apr  8 2003 adrian@suse.de
- update to version 0.0.9
* Tue Apr  8 2003 adrian@suse.de
- initial package of version 0.0.8
